#  (2025-07-05)


### Bug Fixes

* maybe it will work this time ([d7f218c](https://github.com/ashenlabs/depcheckr/commit/d7f218c09972ab05e3b9fc5ac163da57c0f2e6e0))



# [](https://github.com/ashenlabs/depcheckr/compare/v0.1.1...v) (2025-07-05)



#  (2025-07-05)


### Bug Fixes

* command to run tests ([82c38d1](https://github.com/ashenlabs/depcheckr/commit/82c38d1533d6848effa5e67474ca081c076d4f5e))



